@@ -1,15 +1,15 @@
 #define PATCHLEVEL 1.2
 #define PATCHLEVEL_MAJOR 1
 #define PATCHLEVEL_MINOR 2
-#define PATCHLEVEL_SUBMINOR 6
-#define PATCHLEVEL_STRING "1.2.6"
+#define PATCHLEVEL_SUBMINOR 7
+#define PATCHLEVEL_STRING "1.2.7p1"
 
 #define PATCHLEVEL_RELEASE_KIND "release first patches"
 #ifndef PATCHLEVEL_RELEASE_DATE 
 #ifdef RELEASE_DATE
 #define PATCHLEVEL_RELEASE_DATE RELEASE_DATE
 #else
-#define PATCHLEVEL_RELEASE_DATE "$Date: 2004/08/04 11:10:38$"
+#define PATCHLEVEL_RELEASE_DATE "$Date: 2005/11/04 11:54:51$"
 #endif
 #endif
 
